@@ -4,7 +4,7 @@ import cx_Oracle
 import pandas as pd
 from pydantic import Field, SecretStr, constr, create_model
 
-from toucan_connectors.common import convert_to_printf_templating_style
+from toucan_connectors.common import pandas_read_sql
 from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource, strlist_to_enum
 
 
@@ -15,8 +15,7 @@ class OracleSQLDataSource(ToucanDataSource):
     table: constr(min_length=1) = Field(
         None,
         description='The name of the data table that you want to '
-        'get (equivalent to "SELECT * FROM '
-        'your_table")',
+        'get (equivalent to "SELECT * FROM "your_table")',
     )
 
     def __init__(self, **data):
@@ -26,7 +25,7 @@ class OracleSQLDataSource(ToucanDataSource):
         if query is None and table is None:
             raise ValueError("'query' or 'table' must be set")
         elif query is None and table is not None:
-            self.query = f'select * from {table}'
+            self.query = f'SELECT * FROM {table}'
 
     @classmethod
     def get_form(cls, connector: 'OracleSQLConnector', current_config):
@@ -80,8 +79,7 @@ class OracleSQLConnector(ToucanConnector):
         connection = cx_Oracle.connect(**self.get_connection_params())
 
         query = data_source.query[:-1] if data_source.query.endswith(';') else data_source.query
-        query = convert_to_printf_templating_style(query)
-        df = pd.read_sql(query, con=connection)
+        df = pandas_read_sql(query, con=connection)
 
         connection.close()
 
