@@ -334,7 +334,7 @@ class SnowflakeConnector(ToucanConnector):
                     raise TypeError('close is not a function')
 
         connection = snowflake_connection_manager.get(
-            identifier=self.get_identifier(),
+            identifier=f'{self.get_identifier()}{database}{warehouse}',
             connect_method=connect_function,
             alive_method=alive_function,
             close_method=close_function,
@@ -402,6 +402,9 @@ class SnowflakeConnector(ToucanConnector):
             result = SnowflakeCommon().describe(connection, data_source.query)
         return result
 
+    def _render_datasource(self, data_source: SnowflakeDataSource) -> dict:
+        return SnowflakeCommon().render_datasource(data_source)
+
     @staticmethod
     def get_snowflake_connection_manager():
         return snowflake_connection_manager
