@@ -6,7 +6,7 @@ import uuid
 from abc import ABCMeta, abstractmethod
 from enum import Enum
 from functools import reduce, wraps
-from typing import Dict, Iterable, List, NamedTuple, Optional, Type
+from typing import Any, Dict, Iterable, List, NamedTuple, Optional, Type
 
 import pandas as pd
 import tenacity as tny
@@ -32,6 +32,7 @@ class DataStats(NamedTuple):
     execution_time: Optional[float] = None  # query's execution time in ms
     conversion_time: Optional[float] = None  # Result conversion to DataFrame time
     df_memory_size: Optional[int] = None  # Dataframe's memory usage in bytes
+    others: Dict[str, Any] = {}
 
 
 class QueryMetadata(NamedTuple):
@@ -53,6 +54,7 @@ class DataSlice(NamedTuple):
     total_count: Optional[int] = None  # the length of the raw dataframe (without slicing)
     input_parameters: Optional[dict] = None
     stats: Optional[DataStats] = None
+    # TODO: name is kinda misleading. what others information than `columns` will it contain ?
     query_metadata: Optional[QueryMetadata] = None
 
 
@@ -78,7 +80,11 @@ class ToucanDataSource(BaseModel):
     live_data: bool = False
     validation: dict = None
     parameters: dict = None
-    cache_ttl: Optional[int] = None  # overrides connector's ttl
+    cache_ttl: Optional[int] = Field(
+        None,
+        title="Slow Queries' Cache Expiration Time",
+        description='In seconds. Will override the 5min instance default and/or the connector value',
+    )
 
     class Config:
         extra = 'forbid'
@@ -266,7 +272,11 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
 
     # Default ttl for all connector's queries (overridable at the data_source level)
     # /!\ cache ttl is used by the caching system which is not implemented in toucan_connectors.
-    cache_ttl: Optional[int] = Field(None, title='TTL (cache)')
+    cache_ttl: Optional[int] = Field(
+        None,
+        title="Slow Queries' Cache Expiration Time",
+        description='In seconds. Will override the 5min instance default. Can also be overridden at the query level',
+    )
 
     # Used to defined the connection
     identifier: str = Field(None, **{'ui.hidden': True})
@@ -405,6 +415,14 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
         """
         return self.json()
 
+    def _render_datasource(self, data_source: ToucanDataSource) -> dict:
+        data_source_rendered = nosql_apply_parameters_to_query(
+            data_source.dict(), data_source.parameters, handle_errors=True
+        )
+        del data_source_rendered['parameters']
+
+        return data_source_rendered
+
     def get_cache_key(
         self,
         data_source: Optional[ToucanDataSource] = None,
@@ -426,11 +444,7 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
         }
 
         if data_source is not None:
-            data_source_rendered = nosql_apply_parameters_to_query(
-                data_source.dict(), data_source.parameters, handle_errors=True
-            )
-            del data_source_rendered['parameters']
-            unique_identifier['datasource'] = data_source_rendered
+            unique_identifier['datasource'] = self._render_datasource(data_source)
 
         json_uid = JsonWrapper.dumps(unique_identifier, sort_keys=True)
         string_uid = str(uuid.uuid3(uuid.NAMESPACE_OID, json_uid))
